<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>AboutDialog</name>
    <message>
        <source>&amp;Close</source>
        <translation>Za&amp;mknij</translation>
    </message>
</context>
<context>
    <name>AboutLabel</name>
    <message>
        <source>Warning</source>
        <translation>Ostrzeżenie</translation>
    </message>
    <message>
        <source>Unable to launch external application.
</source>
        <translation>Nie można uruchomić zewnętrznej aplikacji.</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Assistant</name>
    <message>
        <source>Error registering documentation file &apos;%1&apos;: %2</source>
        <translation>Błąd podczas zarejestrowania pliku z dokumentacją &quot;%1&quot;: %2</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Błąd: %1</translation>
    </message>
    <message>
        <source>Could not register documentation file
%1

Reason:
%2</source>
        <translation>Nie można zarejestrować pliku z dokumentacją
%1

Powód:
%2</translation>
    </message>
    <message>
        <source>Documentation successfully registered.</source>
        <translation>Dokumentacja poprawnie zarejestrowana.</translation>
    </message>
    <message>
        <source>Could not unregister documentation file
%1

Reason:
%2</source>
        <translation>Nie można wyrejestrować pliku z dokumentacją
%1

Powód:
%2</translation>
    </message>
    <message>
        <source>Documentation successfully unregistered.</source>
        <translation>Dokumentacja poprawnie wyrejestrowana.</translation>
    </message>
    <message>
        <source>Error reading collection file &apos;%1&apos;: %2.</source>
        <translation>Błąd podczas czytania pliku kolekcji &quot;%1&quot;: %2.</translation>
    </message>
    <message>
        <source>Error creating collection file &apos;%1&apos;: %2.</source>
        <translation>Błąd podczas tworzenia pliku kolekcji &quot;%1&quot;: %2.</translation>
    </message>
    <message>
        <source>Cannot load sqlite database driver!</source>
        <translation>Nie można załadować sterownika bazy danych sqlite!</translation>
    </message>
</context>
<context>
    <name>BookmarkDialog</name>
    <message>
        <source>Add Bookmark</source>
        <translation>Dodaj zakładkę</translation>
    </message>
    <message>
        <source>Bookmark:</source>
        <translation>Zakładka:</translation>
    </message>
    <message>
        <source>Add in Folder:</source>
        <translation>Dodaj do katalogu:</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Nowy katalog</translation>
    </message>
    <message>
        <source>Rename Folder</source>
        <translation>Zmień nazwę katalogu</translation>
    </message>
</context>
<context>
    <name>BookmarkItem</name>
    <message>
        <source>New Folder</source>
        <translation>Nowy katalog</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Nienazwany</translation>
    </message>
</context>
<context>
    <name>BookmarkManager</name>
    <message>
        <source>Untitled</source>
        <translation>Nienazwany</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>You are going to delete a Folder, this will also&lt;br&gt;remove it&apos;s content. Are you sure to continue?</source>
        <translation>Zamierzasz usunąć katalog co spowoduje również usunięcie jego zawartości. Czy chcesz kontynuować?</translation>
    </message>
    <message>
        <source>Manage Bookmarks...</source>
        <translation>Zarządzanie zakładkami...</translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation>Dodaj zakładkę...</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>Delete Folder</source>
        <translation>Usuń katalog</translation>
    </message>
    <message>
        <source>Rename Folder</source>
        <translation>Zmień nazwę katalogu</translation>
    </message>
    <message>
        <source>Show Bookmark</source>
        <translation>Pokaż zakładkę</translation>
    </message>
    <message>
        <source>Show Bookmark in New Tab</source>
        <translation>Pokaż zakładkę w nowej karcie</translation>
    </message>
    <message>
        <source>Delete Bookmark</source>
        <translation>Usuń zakładkę</translation>
    </message>
    <message>
        <source>Rename Bookmark</source>
        <translation>Zmień nazwę zakładki</translation>
    </message>
</context>
<context>
    <name>BookmarkManagerWidget</name>
    <message>
        <source>Manage Bookmarks</source>
        <translation>Zarządzanie zakładkami</translation>
    </message>
    <message>
        <source>Search:</source>
        <translation>Wyszukaj:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Import and Backup</source>
        <translation>Import i kopie</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Import...</source>
        <translation>Importuj...</translation>
    </message>
    <message>
        <source>Export...</source>
        <translation>Eksportuj...</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Otwórz plik</translation>
    </message>
    <message>
        <source>Files (*.xbel)</source>
        <translation>Pliki (*.xbel)</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Zachowaj plik</translation>
    </message>
    <message>
        <source>Qt Assistant</source>
        <translation>Qt Assistant</translation>
    </message>
    <message>
        <source>Unable to save bookmarks.</source>
        <translation>Nie można zachować zakładek.</translation>
    </message>
    <message>
        <source>You are goingto delete a Folder, this will also&lt;br&gt; remove it&apos;s content. Are you sure to continue?</source>
        <translation>Zamierzasz usunąć katalog co spowoduje również&lt;br&gt;usunięcie jego zawartości. Czy chcesz kontynuować?</translation>
    </message>
    <message>
        <source>Delete Folder</source>
        <translation>Usuń katalog</translation>
    </message>
    <message>
        <source>Rename Folder</source>
        <translation>Zmień nazwę katalogu</translation>
    </message>
    <message>
        <source>Show Bookmark</source>
        <translation>Pokaż zakładkę</translation>
    </message>
    <message>
        <source>Show Bookmark in New Tab</source>
        <translation>Pokaż zakładkę w nowej karcie</translation>
    </message>
    <message>
        <source>Delete Bookmark</source>
        <translation>Usuń zakładkę</translation>
    </message>
    <message>
        <source>Rename Bookmark</source>
        <translation>Zmień nazwę zakładki</translation>
    </message>
</context>
<context>
    <name>BookmarkModel</name>
    <message>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
    <message>
        <source>Bookmarks Toolbar</source>
        <translation>Pasek z zakładkami</translation>
    </message>
    <message>
        <source>Bookmarks Menu</source>
        <translation>Menu zakładek</translation>
    </message>
</context>
<context>
    <name>BookmarkWidget</name>
    <message>
        <source>Bookmarks</source>
        <translation>Zakładki</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filtr:</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Usuń</translation>
    </message>
</context>
<context>
    <name>CentralWidget</name>
    <message>
        <source>Print Document</source>
        <translation>Wydrukuj dokument</translation>
    </message>
</context>
<context>
    <name>CmdLineParser</name>
    <message>
        <source>Usage: assistant [Options]

-collectionFile file       Uses the specified collection
                           file instead of the default one
-showUrl url               Shows the document with the
                           url.
-enableRemoteControl       Enables Assistant to be
                           remotely controlled.
-show widget               Shows the specified dockwidget
                           which can be &quot;contents&quot;, &quot;index&quot;,
                           &quot;bookmarks&quot; or &quot;search&quot;.
-activate widget           Activates the specified dockwidget
                           which can be &quot;contents&quot;, &quot;index&quot;,
                           &quot;bookmarks&quot; or &quot;search&quot;.
-hide widget               Hides the specified dockwidget
                           which can be &quot;contents&quot;, &quot;index&quot;
                           &quot;bookmarks&quot; or &quot;search&quot;.
-register helpFile         Registers the specified help file
                           (.qch) in the given collection
                           file.
-unregister helpFile       Unregisters the specified help file
                           (.qch) from the give collection
                           file.
-setCurrentFilter filter   Set the filter as the active filter.
-remove-search-index       Removes the full text search index.
-rebuild-search-index      Re-builds the full text search index (potentially slow).
-quiet                     Does not display any error or
                           status message.
-help                      Displays this help.
</source>
        <translation>Sposób użycia: assistant [opcje]

-collectionFile plik       Używa podanego pliku kolekcji
                           zamiast domyślnego.
-showUrl url               Pokazuje dokument z
                           url.
-enableRemoteControl       Umożliwia zdalną kontrolę
                           nad Assistantem.
-show widżet               Pokazuje podany widżet
                           dokowalny, którym może być &quot;contents&quot;, &quot;index&quot;,
                           &quot;bookmarks&quot; albo &quot;search&quot;.
-activate widżet           Aktywuje podany widżet
                           dokowalny, którym może być &quot;contents&quot;, &quot;index&quot;,
                           &quot;bookmarks&quot; albo &quot;search&quot;.
-hide widżet               Ukrywa podany widżet
                           dokowalny, którym może być &quot;contents&quot;, &quot;index&quot;,
                           &quot;bookmarks&quot; albo &quot;search&quot;.
-register plikPomocy       Rejestruje podany plik pomocy
                           (.qch) w podanym pliku kolekcji.
-unregister plikPomocy     Wyrejestrowuje podany plik pomocy
                           (.qch) w podanym pliku kolekcji.
-setCurrentFilter filtr    Ustawia filtr jako aktywny.
-remove-search-index       Usuwa indeks pełnego przeszukiwania tekstu.
-rebuild-search-index      Przebudowuje indeks pełnego
                           przeszukiwania tekstu (potencjalnie wolne).
-quiet                     Nie pokazuje żadnych błędów ani
                           komunikatów o stanie.
-help                      Pokazuje tę pomoc.
</translation>
    </message>
    <message>
        <source>Unknown option: %1</source>
        <translation>Nieznana opcja: %1</translation>
    </message>
    <message>
        <source>The collection file &apos;%1&apos; does not exist.</source>
        <translation>Plik kolekcji &quot;%1&quot; nie istnieje.</translation>
    </message>
    <message>
        <source>Missing collection file.</source>
        <translation>Brak pliku kolekcji.</translation>
    </message>
    <message>
        <source>Invalid URL &apos;%1&apos;.</source>
        <translation>Niepoprawny URL &quot;%1&quot;.</translation>
    </message>
    <message>
        <source>Missing URL.</source>
        <translation>Brak URL.</translation>
    </message>
    <message>
        <source>Unknown widget: %1</source>
        <translation>Nieznany widżet: %1</translation>
    </message>
    <message>
        <source>Missing widget.</source>
        <translation>Brak widżetu.</translation>
    </message>
    <message>
        <source>The Qt help file &apos;%1&apos; does not exist.</source>
        <translation>Plik pomocy Qt &quot;%1&quot; nie istnieje.</translation>
    </message>
    <message>
        <source>Missing help file.</source>
        <translation>Brak pliku pomocy.</translation>
    </message>
    <message>
        <source>Missing filter argument.</source>
        <translation>Brak argumentu dla filtru.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Uwaga</translation>
    </message>
</context>
<context>
    <name>ContentWindow</name>
    <message>
        <source>Open Link</source>
        <translation>Otwórz odsyłacz</translation>
    </message>
    <message>
        <source>Open Link in New Tab</source>
        <translation>Otwórz odsyłacz w nowej karcie</translation>
    </message>
</context>
<context>
    <name>FilterNameDialogClass</name>
    <message>
        <source>Add Filter Name</source>
        <translation>Dodaj nazwę filtru</translation>
    </message>
    <message>
        <source>Filter Name:</source>
        <translation>Nazwa filtru:</translation>
    </message>
</context>
<context>
    <name>FindWidget</name>
    <message>
        <source>Previous</source>
        <translation>Poprzedni</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Następny</translation>
    </message>
    <message>
        <source>Case Sensitive</source>
        <translation>Uwzględniaj wielkość liter</translation>
    </message>
    <message>
        <source>&lt;img src=&quot;:/qt-project.org/assistant/images/wrap.png&quot;&gt;&amp;nbsp;Search wrapped</source>
        <translation>&lt;img src=&quot;:/qt-project.org/assistant/images/wrap.png&quot;&gt;&amp;nbsp;Przeszukano od początku</translation>
    </message>
</context>
<context>
    <name>FontPanel</name>
    <message>
        <source>Font</source>
        <translation>Czcionka</translation>
    </message>
    <message>
        <source>&amp;Writing system</source>
        <translation>Sys&amp;tem pisania</translation>
    </message>
    <message>
        <source>&amp;Family</source>
        <translation>&amp;Rodzina</translation>
    </message>
    <message>
        <source>&amp;Style</source>
        <translation>&amp;Styl</translation>
    </message>
    <message>
        <source>&amp;Point size</source>
        <translation>&amp;Wielkość punktu</translation>
    </message>
</context>
<context>
    <name>GlobalActions</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Wstecz</translation>
    </message>
    <message>
        <source>&amp;Forward</source>
        <translation>W &amp;przód</translation>
    </message>
    <message>
        <source>&amp;Home</source>
        <translation>Strona &amp;startowa</translation>
    </message>
    <message>
        <source>ALT+Home</source>
        <translation>ALT+Home</translation>
    </message>
    <message>
        <source>Zoom &amp;in</source>
        <translation>Po&amp;większ</translation>
    </message>
    <message>
        <source>Zoom &amp;out</source>
        <translation>Po&amp;mniejsz</translation>
    </message>
    <message>
        <source>&amp;Copy selected Text</source>
        <translation>S&amp;kopiuj zaznaczony tekst</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>&amp;Drukuj...</translation>
    </message>
    <message>
        <source>&amp;Find in Text...</source>
        <translation>Znajdź w &amp;tekście...</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Znajdź</translation>
    </message>
</context>
<context>
    <name>HelpEngineWrapper</name>
    <message>
        <source>Unfiltered</source>
        <translation>Nieprzefiltrowane</translation>
    </message>
</context>
<context>
    <name>HelpViewer</name>
    <message>
        <source>&lt;title&gt;about:blank&lt;/title&gt;</source>
        <translation>&lt;title&gt;informacje o:pusty&lt;/title&gt;</translation>
    </message>
    <message>
        <source>&lt;title&gt;Error 404...&lt;/title&gt;&lt;div align=&quot;center&quot;&gt;&lt;br&gt;&lt;br&gt;&lt;h1&gt;The page could not be found.&lt;/h1&gt;&lt;br&gt;&lt;h3&gt;&apos;%1&apos;&lt;/h3&gt;&lt;/div&gt;</source>
        <translation>&lt;title&gt;Błąd 404...&lt;/title&gt;&lt;div align=&quot;center&quot;&gt;&lt;br&gt;&lt;br&gt;&lt;h1&gt;Strona nie może zostać odnaleziona.&lt;/h1&gt;&lt;br&gt;&lt;h3&gt;&apos;%1&apos;&lt;/h3&gt;&lt;/div&gt;</translation>
    </message>
    <message>
        <source>Open Link</source>
        <translation>Otwórz odsyłacz</translation>
    </message>
    <message>
        <source>Copy &amp;Link Location</source>
        <translation>Skopiuj &amp;odsyłacz</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Skopiuj</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Przeładuj</translation>
    </message>
    <message>
        <source>Open Link in New Tab	Ctrl+LMB</source>
        <translation>Otwórz odsyłacz w nowej karcie	Ctrl+LMB</translation>
    </message>
    <message>
        <source>Open Link in New Page</source>
        <translation>Otwórz odsyłacz na nowej stronie</translation>
    </message>
    <message>
        <source>Error 404...</source>
        <translation>Błąd 404...</translation>
    </message>
    <message>
        <source>The page could not be found!</source>
        <translation>Strona nie może zostać odnaleziona.</translation>
    </message>
    <message>
        <source>Please make sure that you have all documentation sets installed.</source>
        <translation>Proszę sprawdzić, czy zainstalowano wszystkie zestawy dokumentacji.</translation>
    </message>
    <message>
        <source>Error loading: %1</source>
        <translation>Błąd ładowania: %1</translation>
    </message>
</context>
<context>
    <name>IndexWindow</name>
    <message>
        <source>&amp;Look for:</source>
        <translation>Wy&amp;szukaj:</translation>
    </message>
    <message>
        <source>Open Link</source>
        <translation>Otwórz odsyłacz</translation>
    </message>
    <message>
        <source>Open Link in New Tab</source>
        <translation>Otwórz odsyłacz w nowej karcie</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Index</source>
        <translation>Indeks</translation>
    </message>
    <message>
        <source>Contents</source>
        <translation>Spis treści</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Zakładki</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Wyszukaj</translation>
    </message>
    <message>
        <source>Qt Assistant</source>
        <translation>Qt Assistant</translation>
    </message>
    <message>
        <source>Page Set&amp;up...</source>
        <translation>&amp;Ustawienia strony...</translation>
    </message>
    <message>
        <source>Print Preview...</source>
        <translation>Podgląd wydruku...</translation>
    </message>
    <message>
        <source>New &amp;Tab</source>
        <translation>Nowa kar&amp;ta</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Zamknij kartę</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Za&amp;kończ</translation>
    </message>
    <message>
        <source>CTRL+Q</source>
        <translation>CTRL+Q</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>Znajdź &amp;następny</translation>
    </message>
    <message>
        <source>Find &amp;Previous</source>
        <translation>Znajdź &amp;poprzedni</translation>
    </message>
    <message>
        <source>Preferences...</source>
        <translation>Ustawienia...</translation>
    </message>
    <message>
        <source>Normal &amp;Size</source>
        <translation>Normalny &amp;rozmiar</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>ALT+C</source>
        <translation>ALT+C</translation>
    </message>
    <message>
        <source>ALT+I</source>
        <translation>ALT+I</translation>
    </message>
    <message>
        <source>ALT+S</source>
        <translation>ALT+S</translation>
    </message>
    <message>
        <source>Sync with Table of Contents</source>
        <translation>Znajdź bieżącą stronę w spisie treści</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>Zsynchronizuj</translation>
    </message>
    <message>
        <source>Next Page</source>
        <translation>Następna strona</translation>
    </message>
    <message>
        <source>Ctrl+Alt+Right</source>
        <translation></translation>
    </message>
    <message>
        <source>Previous Page</source>
        <translation>Poprzednia strona</translation>
    </message>
    <message>
        <source>Ctrl+Alt+Left</source>
        <translation></translation>
    </message>
    <message>
        <source>Could not register file &apos;%1&apos;: %2</source>
        <translation>Nie można zarejestrować pliku &quot;%1&quot;: %2</translation>
    </message>
    <message>
        <source>About...</source>
        <translation>Informacje o programie...</translation>
    </message>
    <message>
        <source>Open Pages</source>
        <translation>Otwarte strony</translation>
    </message>
    <message>
        <source>Bookmark Toolbar</source>
        <translation>Pasek z zakładkami</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>Za&amp;kończ</translation>
    </message>
    <message>
        <source>ALT+P</source>
        <translation>ALT+P</translation>
    </message>
    <message>
        <source>Navigation Toolbar</source>
        <translation>Pasek do nawigacji</translation>
    </message>
    <message>
        <source>Toolbars</source>
        <translation>Paski narzędzi</translation>
    </message>
    <message>
        <source>Filter Toolbar</source>
        <translation>Pasek filtrowania</translation>
    </message>
    <message>
        <source>Filtered by:</source>
        <translation>Przefiltrowane przez:</translation>
    </message>
    <message>
        <source>Address Toolbar</source>
        <translation>Pasek adresu</translation>
    </message>
    <message>
        <source>Address:</source>
        <translation>Adres:</translation>
    </message>
    <message>
        <source>Could not find the associated content item.</source>
        <translation>Nie można znaleźć skojarzonego elementu zawartości.</translation>
    </message>
    <message>
        <source>&lt;center&gt;&lt;h3&gt;%1&lt;/h3&gt;&lt;p&gt;Version %2&lt;/p&gt;&lt;p&gt;Browser: %3&lt;/p&gt;&lt;/center&gt;&lt;p&gt;Copyright (C) %4 The Qt Company Ltd.&lt;/p&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>Informacje o %1</translation>
    </message>
    <message>
        <source>Updating search index</source>
        <translation>Uaktualnianie indeksu wyszukiwawczego</translation>
    </message>
    <message>
        <source>Looking for Qt Documentation...</source>
        <translation>Szukanie dokumentacji Qt...</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Okno</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Zminimalizuj</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation></translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation>Powiększenie</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Plik</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Edycja</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Widok</translation>
    </message>
    <message>
        <source>&amp;Go</source>
        <translation>&amp;Nawigacja</translation>
    </message>
    <message>
        <source>&amp;Bookmarks</source>
        <translation>&amp;Zakładki</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Pomoc</translation>
    </message>
    <message>
        <source>ALT+O</source>
        <translation>ALT+O</translation>
    </message>
</context>
<context>
    <name>OpenPagesWidget</name>
    <message>
        <source>Close %1</source>
        <translation>Zamknij %1</translation>
    </message>
    <message>
        <source>Close All Except %1</source>
        <translation>Zamknij wszystko z wyjątkiem %1</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Add Documentation</source>
        <translation>Dodaj dokumentację</translation>
    </message>
    <message>
        <source>Qt Compressed Help Files (*.qch)</source>
        <translation>Skompresowane pliki pomocy Qt (*.qch)</translation>
    </message>
    <message>
        <source>The specified file is not a valid Qt Help File!</source>
        <translation>Podany plik nie jest poprawnym plikiem pomocy Qt!</translation>
    </message>
    <message>
        <source>The namespace %1 is already registered!</source>
        <translation>Przestrzeń nazw %1 jest już zarejestrowana!</translation>
    </message>
    <message>
        <source>Remove Documentation</source>
        <translation>Usuń dokumentację</translation>
    </message>
    <message>
        <source>Some documents currently opened in Assistant reference the documentation you are attempting to remove. Removing the documentation will close those documents.</source>
        <translation>Niektóre dokumenty otwarte w Assistant odwołują sie do dokumentacji którą próbujesz usunąć. Usunięcie dokumentacji spowoduje zamknięcie tych dokumentów.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Use custom settings</source>
        <translation>Użyj własnych ustawień</translation>
    </message>
</context>
<context>
    <name>PreferencesDialogClass</name>
    <message>
        <source>Preferences</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>Czcionki</translation>
    </message>
    <message>
        <source>Font settings:</source>
        <translation>Ustawienia czcionki:</translation>
    </message>
    <message>
        <source>Browser</source>
        <translation>Przeglądarka</translation>
    </message>
    <message>
        <source>Application</source>
        <translation>Aplikacja</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Filtry</translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation>Filtr:</translation>
    </message>
    <message>
        <source>Attributes:</source>
        <translation>Atrybuty:</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>Dokumentacja</translation>
    </message>
    <message>
        <source>Registered Documentation:</source>
        <translation>Zarejestrowana dokumentacja:</translation>
    </message>
    <message>
        <source>Add...</source>
        <translation>Dodaj...</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opcje</translation>
    </message>
    <message>
        <source>Current Page</source>
        <translation>Bieżąca strona</translation>
    </message>
    <message>
        <source>Restore to default</source>
        <translation>Przywróć domyślną</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Strona startowa</translation>
    </message>
    <message>
        <source>On help start:</source>
        <translation>Po uruchomieniu:</translation>
    </message>
    <message>
        <source>Show my home page</source>
        <translation>Pokaż stronę startową</translation>
    </message>
    <message>
        <source>Show a blank page</source>
        <translation>Pokaż pustą stronę</translation>
    </message>
    <message>
        <source>Show my tabs from last session</source>
        <translation>Pokaż moje karty z ostatniej sesji</translation>
    </message>
    <message>
        <source>Blank Page</source>
        <translation>Pusta strona</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Wygląd</translation>
    </message>
    <message>
        <source>Show tabs for each individual page</source>
        <translation>Pokazuj karty dla każdej otwartej strony</translation>
    </message>
    <message>
        <source>&lt;Filter&gt;</source>
        <translation>&lt;Filtr&gt;</translation>
    </message>
</context>
<context>
    <name>RemoteControl</name>
    <message>
        <source>Debugging Remote Control</source>
        <translation>Zdalne debugowanie</translation>
    </message>
    <message>
        <source>Received Command: %1 %2</source>
        <translation>Odebrano komendę: %1 %2</translation>
    </message>
</context>
<context>
    <name>SearchWidget</name>
    <message>
        <source>&amp;Copy</source>
        <translation>S&amp;kopiuj</translation>
    </message>
    <message>
        <source>Copy &amp;Link Location</source>
        <translation>Skopiuj &amp;odsyłacz</translation>
    </message>
    <message>
        <source>Open Link in New Tab</source>
        <translation>Otwórz odsyłacz w nowej karcie</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Zaznacz wszystko</translation>
    </message>
</context>
<context>
    <name>TabBar</name>
    <message>
        <source>(Untitled)</source>
        <translation>(Nienazwany)</translation>
    </message>
    <message>
        <source>New &amp;Tab</source>
        <translation>Nowa kar&amp;ta</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Zamknij kartę</translation>
    </message>
    <message>
        <source>Close Other Tabs</source>
        <translation>Zamknij pozostałe karty</translation>
    </message>
    <message>
        <source>Add Bookmark for this Page...</source>
        <translation>Dodaj zakładkę dla tej strony...</translation>
    </message>
</context>
<context>
    <name>TopicChooser</name>
    <message>
        <source>Filter</source>
        <translation>Filtr</translation>
    </message>
    <message>
        <source>Choose a topic for &lt;b&gt;%1&lt;/b&gt;:</source>
        <translation>Wybierz temat dla &lt;b&gt;%1&lt;/b&gt;:</translation>
    </message>
    <message>
        <source>Choose Topic</source>
        <translation>Wybierz temat</translation>
    </message>
    <message>
        <source>&amp;Topics</source>
        <translation>&amp;Tematy</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Pokaż</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
</context>
</TS>
